/*
 * Copyright 2005, 2006 University of Leiden.
 *
 * This file is part of MIA+EWS.
 *
 * MIA+EWS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * MIA+EWS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with MIA; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/*******************************************************************************
* E.S.O. - VLT project
*
* "@(#) $Id: FOfit.h,v 1.4 2002/05/08 21:24:47 jdejong Exp $"
*
* who       when      what
* --------  --------  ----------------------------------------------
* jdejong 2002-05-08  imported
*/

/************************************************************************
 *
 *----------------------------------------------------------------------
 */
/* $Id: FOfit.h,v 1.4 2002/05/08 21:24:47 jdejong Exp $ */

#ifndef _FOFIT_H
#define _FOFIT_H
/*----------------------------------------------------------------------- */
/* Routines and parameters for MIDI Fourier Mode fringe fitting           */
/*----------------------------------------------------------------------- */
#include <time.h>
#include <math.h>
#include <malloc.h>
#include <string.h>
#include <stdio.h>
#include <stdlib.h>
#include "imaging_detector.h"
#include "cal_table.h"
#include "visibility.h"
#include "image.h"
#include "history.h"

void setup_FOfringe_fit(char *pixfile, fitsfile *inputfptr, 
			int nt, int nscan, 
			float time_incr, float OPD_incr,
			imaging_detector_table_def* detector);
/*----------------------------------------------------------------------- */
/*   Setup for fit MIDI Fourier Mode (undispersed) data                   */
/*   Necessary structures are allocated.                                  */
/*   Inputs:                                                              */
/*      pixfile   name of output Delay-rate image, NULL=>don't write      */
/*      inputfptr input file cfitsio pointer                              */
/*      nt        Number of samples per scan                              */
/*      nscan     Max. number of scans per solution                       */
/*      time_incr Time step between samples in sec                        */
/*      ODP_incr  OPD step between samples in sec                         */
/*      detector  imaging_detector table definition structure             */
/*----------------------------------------------------------------------- */

void FOfringe_fit_data (float **IntChan, int nt, int nscan, float time_incr,
		      float **OPD_off, float **times, 
		      imaging_detector_table_def* detector,
		      cal_table_row *cal_row);
/*----------------------------------------------------------------------- */
/*   Fit delay and rate for MIDI Fourier Mode (undispersed) data          */
/*   Notes:                                                               */
/*    1) setup_FOfringe_fit must be called before first call to           */
/*       FOfringe_fit_data                                                */
/*    2) shutdown_FOfringe_fit should be called after last call to        */
/*       FOfringe_fit_data                                                */
/*                                                                        */
/*   Steps:                                                               */
/*   Inputs:                                                              */
/*      IntChan   Difference array of two interferometric channels        */
/*                as complex values [scan][frame]                         */
/*      nt        Number of frames in a scan                              */
/*      nscan     Number of scans  in IntChan                             */
/*      time_incr Time step between frames in sec                         */
/*      OPD_off   OPD offset applied (seconds) [scan][frame]              */
/*      times     Times relative to reference time (sec) [scan][frame]    */
/*      detector  imaging_detector table definition structure             */
/*   Outputs:                                                             */
/*      cal_row   calibration table structure for result, ignore if NULL  */
/*----------------------------------------------------------------------- */

int  FO_calib_data (float *IntChan, int nt, int iscan, int nscan, 
		    float OPD_range, float calDelay, float calPhase, 
		    float calRate, float weight,
		    visibility_row *visrow);
/*----------------------------------------------------------------------- */
/*   Apply calibration to MIDI Fourier mode (undispersed) data            */
/*   Steps:                                                               */
/*   Inputs:                                                              */
/*      IntChan   Difference array of two interferometric channels        */
/*                as complex values.                                      */
/*      nt        Number of frames in a scan                              */
/*      iscan     Which scan is this in the sequence                      */
/*      nscan     Total number of scans in the sequence                   */
/*      OPD_range Range of modulation OPD in a scan (sec)                 */
/*      calDelay  Calibration delay (seconds)                             */
/*      calPhase  Calibration phase (radians)                             */
/*      calDelay  Calibration rate (sec/sec)                              */
/*      weight    data weight for this interferogram                      */
/*   Outputs:                                                             */
/*      visrow    Visibility record, filled in on output                  */
/*   Returns                                                              */
/*      1 if there is valid data in the average and iscan=nscan, else 0   */
/*----------------------------------------------------------------------- */

void shutdown_FOfringe_fit(int *ierr);
/*----------------------------------------------------------------------- */
/*   Shutdown fit to MIDI Fourier Mode (undispersed) data                 */
/*   All allocated structures are deleted.                                */ 
/*   Outputs:                                                             */
/*      ierr        Error code: 0 => ok                                   */
/*----------------------------------------------------------------------- */

#endif /* end FOFIT_H */

/* */
